@@ -3,5 +3,5 @@ from .models import InstalacaoAtivo
 
 
 @admin.register(InstalacaoAtivo)
-class InstalacaoativoAdmin(admin.ModelAdmin):
-   list_display = ('id', 'comments')
+class InstalacaoAtivoAdmin(admin.ModelAdmin):
+    list_display = ('id', 'comments')
